var multiplier = Ti.Platform.osname == 'android' ? 3 : 1;

exports.makeTabbedBar = function (_params, _fn) {
	var wrapper = Ti.UI.createView({
		layout: 'horizontal',
		horizontalWrap: false,
		height: 45 * multiplier,
		width: Ti.UI.FILL,
		index: _params.index || 0,
		backgroundColor: "white"
	});

	_params.colorActive = "#666666";
	_params.colorInactive = "#2AA3EF";

	var numButtons = _params.labels.length;
	var subBtnWidth = Math.floor(100 / numButtons);
	var last = numButtons - 1;
	var btnArray = [];
	var indicatorArray = [];

	for (var i = 0; i < numButtons; i++) {
		var selected = i == wrapper.index;

		var btnContainer = Ti.UI.createView({
			height: Ti.UI.FILL,
			width: i == last ? Ti.UI.FILL : subBtnWidth + '%'
		});

		var lblContainer = Ti.UI.createView({
			height: 40 * multiplier,
			width: Ti.UI.FILL,
			myIndex: i
		});

		var subLabel = Ti.UI.createLabel({
			height: Ti.UI.FILL,
			width: Ti.UI.FILL,
			top: 0,
			left: 5 * multiplier,
			right: 5 * multiplier,
			textAlign: Ti.UI.TEXT_ALIGNMENT_CENTER,
			ellipsize: Ti.UI.TEXT_ELLIPSIZE_TRUNCATE_END,
			maxLines: 2,
			color: selected ? _params.colorActive : _params.colorInactive,
			text: _params.labels[i],
			touchEnabled: false,
			font: {
				fontSize: 14 * multiplier,
				fontWeight: selected ? "bold" : "normal"
			}
		});

		btnArray.push(subLabel);
		lblContainer.add(subLabel);
		btnContainer.add(lblContainer);

		var indicator = Ti.UI.createView({
			height: 5 * multiplier,
			width: Ti.UI.FILL,
			bottom: 0,
			backgroundColor: _params.colorActive,
			visible: selected ? true : false,
			touchEnabled: false
		});

		indicatorArray.push(indicator);
		btnContainer.add(indicator);
		wrapper.add(btnContainer);
	}

	wrapper.addEventListener('click', function (e) {
		if (e.source.myIndex >= 0) {
			if (wrapper.index >= 0) {
				btnArray[wrapper.index].applyProperties({
					color: _params.colorInactive,
					font: {
						fontSize: 14 * multiplier,
						fontWeight: "normal"
					}
				});
				indicatorArray[wrapper.index].hide();
			}

			wrapper.index = e.source.myIndex;

			btnArray[wrapper.index].applyProperties({
				color: _params.colorActive,
				font: {
					fontSize: 14 * multiplier,
					fontWeight: "bold"
				}
			});
			indicatorArray[wrapper.index].show();

			if (_fn) _fn(wrapper.index);
		}
	});

	return wrapper;
};